summaryrefslogtreecommitdiffstats
path: root/components/suggestions
diff options
context:
space:
mode:
authormathp@chromium.org <mathp@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-08-08 08:33:38 +0000
committermathp@chromium.org <mathp@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-08-08 08:34:52 +0000
commit93b41658eff6edc79490e51040825ef31b5dfec3 (patch)
tree257ddb318adcdaafae9a6d0c64781b15534f06fb /components/suggestions
parentd96ab4a3aca71cdd134ba92cbf1afb6a9bc7d72a (diff)
downloadchromium_src-93b41658eff6edc79490e51040825ef31b5dfec3.zip
chromium_src-93b41658eff6edc79490e51040825ef31b5dfec3.tar.gz
chromium_src-93b41658eff6edc79490e51040825ef31b5dfec3.tar.bz2
[Suggestions] Rename ThumbnailManager to ImageManagerImpl
For future use with favicons, remove reference to "thumbnail". There is no functionality change in this CL, just a rename. BUG=388747 TEST=ImageManager* Review URL: https://codereview.chromium.org/445753004 Cr-Commit-Position: refs/heads/master@{#288260} git-svn-id: svn://svn.chromium.org/chrome/trunk/src@288260 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'components/suggestions')
-rw-r--r--components/suggestions/proto/suggestions.proto6
1 files changed, 3 insertions, 3 deletions
diff --git a/components/suggestions/proto/suggestions.proto b/components/suggestions/proto/suggestions.proto
index aaf5ef6..cb40e63 100644
--- a/components/suggestions/proto/suggestions.proto
+++ b/components/suggestions/proto/suggestions.proto
@@ -52,11 +52,11 @@ message SuggestionsBlacklist {
repeated string urls = 1;
}
// ThumbnailData contains the data to represent a website thumbnail.
//
// Next tag: 3
-message ThumbnailData {
- // The URL of the website represented by this Thumbnail.
+message ImageData {
+ // The URL of the website represented by this image.
optional string url = 1;
// Bitmap bytes, encoded as JPEG.
@@ -52,11 +52,11 @@ message SuggestionsBlacklist {
repeated string urls = 1;
}
-// ThumbnailData contains the data to represent a website thumbnail.
+// ImageData contains the data to represent a website image (e.g. thumbnail).
//
// Next tag: 3